import { request, getRequestParams } from '@/utils/request';

/**
 * 创建课程
 * @param {Object} data
 */
export function CreateCourse(data) {
  let params = getRequestParams('teaching-course_manager-CreateCourse');

  return request({
    method: 'post',
    url: process.env.VUE_APP_LearnWebSI,
    params,
    data
  });
}

/**
 * 修改课程
 * @param {Object} data
 * @returns
 */
export function UpdateCourse(data) {
  let params = getRequestParams('teaching-course_manager-UpdateCourse');

  return request({
    method: 'post',
    url: process.env.VUE_APP_LearnWebSI,
    params,
    data
  });
}

/**
 * 得到课程信息（包含课节信息）
 * @param {Object} { id 课程ID }
 */
export function GetCourseInfo_ContainCSItem(data) {
  let params = getRequestParams('teaching-course_manager-GetCourseInfo_ContainCSItem');

  return request({
    method: 'post',
    url: process.env.VUE_APP_LearnWebSI,
    params,
    data
  });
}

/**
 * 添加教材到课程
 * @param {Object} course_id 课程id book_id 教材ID
 */
export function AddBookToCourse(data) {
  let params = getRequestParams('teaching-course_manager-AddBookToCourse');

  return request({
    method: 'post',
    url: process.env.VUE_APP_LearnWebSI,
    params,
    data
  });
}

/**
 * 从课程移除教材
 * @param {Object} course_id 课程ID book_id 教材ID
 */
export function RemoveBookFromCourse(data) {
  let params = getRequestParams('teaching-course_manager-RemoveBookFromCourse');

  return request({
    method: 'post',
    url: process.env.VUE_APP_LearnWebSI,
    params,
    data
  });
}

/**
 * 添加课节到课程
 * @param {Object} data course_id 课程ID begin_time 开始时间 end_time 截止时间 name 课节名称
 */
export function AddCSItemToCourse(data) {
  let params = getRequestParams('teaching-cs_item_manager-AddCSItemToCourse');

  return request({
    method: 'post',
    url: process.env.VUE_APP_LearnWebSI,
    params,
    data
  });
}

/**
 * 得到课节详情（信息集合）
 * @param {Object} data id 课次id
 */
export function GetCSItemInfoBox(data) {
  let params = getRequestParams('teaching-cs_item_manager-GetCSItemInfoBox');

  return request({
    method: 'post',
    url: process.env.VUE_APP_LearnWebSI,
    params,
    data
  });
}

/**
 * 得到课节
 * @param {Object} data { id 课节ID }
 */
export function GetCSItem(data) {
  let params = getRequestParams('teaching-cs_item_manager-GetCSItem');

  return request({
    method: 'post',
    url: process.env.VUE_APP_LearnWebSI,
    params,
    data
  });
}

/**
 * 修改课节
 * @param {Object} data
 */
export function UpdateCSItem(data) {
  let params = getRequestParams('teaching-cs_item_manager-UpdateCSItem');

  return request({
    method: 'post',
    url: process.env.VUE_APP_LearnWebSI,
    params,
    data
  });
}

/**
 * 删除课节
 * @param {Object} data id 课次ID
 */
export function DeleteCSItem(data) {
  let params = getRequestParams('teaching-cs_item_manager-DeleteCSItem');

  return request({
    method: 'post',
    url: process.env.VUE_APP_LearnWebSI,
    params,
    data
  });
}

/**
 * 添加任务到课节
 * @param {Object} data
 * @returns
 */
export function AddTaskToCSItem(data) {
  let params = getRequestParams('teaching-task_manager-AddTaskToCSItem');

  return request({
    method: 'post',
    url: process.env.VUE_APP_LearnWebSI,
    params,
    data
  });
}

/**
 * 得到教材章节结构
 * @param {Object} data { book_id 教材ID }
 */
export function GetBookChapterStruct(data) {
  let params = getRequestParams('book-book_manager-GetBookChapterStruct');

  return request({
    method: 'post',
    url: process.env.VUE_APP_BookWebSI,
    params,
    data
  });
}

/**
 * 得到树节点信息（教材章节结构）
 * @param data { id 节点ID }
 */
export function GetTreeNodeInfo_BookChapterStruct(data) {
  let params = getRequestParams('book-book_manager-GetTreeNodeInfo_BookChapterStruct');

  return request({
    method: 'post',
    url: process.env.VUE_APP_BookWebSI,
    params,
    data
  });
}

/**
 * 审核课程学员
 * @param {Object} data { course_student_id 课程学员绑定ID is_audited 审核 }
 */
export function AuditCourseStudent(data) {
  let params = getRequestParams('teaching-course_manager-AuditCourseStudent');

  return request({
    method: 'post',
    url: process.env.VUE_APP_LearnWebSI,
    params,
    data
  });
}

/**
 * 得到互动课件内容（展示内容）
 * @param {Object} data { id 互动课件ID }
 */
export function GetCoursewareContent_View(data) {
  let params = getRequestParams('book-courseware_manager-GetCoursewareContent_View');

  return request({
    method: 'post',
    url: process.env.VUE_APP_BookWebSI,
    params,
    data
  });
}

/**
 * 得到任务信息
 * @param {Object} data { id 任务 ID }
 */
export function GetTaskInfo(data) {
  let params = getRequestParams('teaching-task_manager-GetTaskInfo');

  return request({
    method: 'post',
    url: process.env.VUE_APP_LearnWebSI,
    params,
    data
  });
}

/**
 * 修改任务
 * @param {Object} data
 */
export function UpdateTask(data) {
  let params = getRequestParams('teaching-task_manager-UpdateTask');

  return request({
    method: 'post',
    url: process.env.VUE_APP_LearnWebSI,
    params,
    data
  });
}

/**
 * 得到课程详情
 * @param {Object} data {id 课次ID}
 */
export function GetCourseInfoBox(data) {
  let params = getRequestParams('cominfo_query-course_query-GetCourseInfoBox');

  return request({
    method: 'post',
    url: process.env.VUE_APP_LearnWebSI,
    params,
    data
  });
}
