import { request, getRequestParams } from '@/utils/request';

/**
 * 创建进入直播教室的会话
 * @param data { task_id 任务ID }
 */
export function CreateEnterLiveRoomSession(data) {
  let params = getRequestParams('live_room-live_room_dispatch-CreateEnterLiveRoomSession');

  return request({
    method: 'post',
    url: process.env.VUE_APP_LearnWebSI,
    params,
    data
  });
}

/**
 * 关闭直播
 * @param { Object } data { task_id 任务ID }
 */
export function CloseLiveRoom(data) {
  let params = getRequestParams('live_room-live_room_dispatch-CloseLiveRoom');

  return request({
    method: 'post',
    url: process.env.VUE_APP_LearnWebSI,
    params,
    data
  });
}

/**
 * 得到直播间学员列表
 * @param {Object} data { task_id 任务ID }
 */
export function GetLiveRoomStudentList(data) {
  let params = getRequestParams('live_room-live_room_dispatch-GetLiveRoomStudentList');

  return request({
    method: 'post',
    url: process.env.VUE_APP_LearnWebSI,
    params,
    data
  });
}

/**
 * 学员退出直播间
 * @param {Object} data { task_id 任务ID, room_user_id 学员所在直播间的用户ID}
 */
export function StudentExitLiveRoom(data) {
  let params = getRequestParams('live_room-live_room_dispatch-StudentExitLiveRoom');

  return request({
    method: 'post',
    url: process.env.VUE_APP_LearnWebSI,
    params,
    data
  });
}

/**
 * 得到可以推送的资料列表（课件或文档）
 * @param {Object} data { task_id 任务ID }
 */
export function GetMaterialListForSendToStudent(data) {
  let params = getRequestParams('live_room-live_room_dispatch-GetMaterialListForSendToStudent');

  return request({
    method: 'post',
    url: process.env.VUE_APP_LearnWebSI,
    params,
    data
  });
}

/**
 * 推送资料
 * @param {Object} data
 */
export function SendMaterial(data) {
  let params = getRequestParams('live_room-live_room_dispatch-SendMaterial');

  return request({
    method: 'post',
    url: process.env.VUE_APP_LearnWebSI,
    params,
    data
  });
}

/**
 * 获取当前推送的资料
 * @param {Object} data {task_id 任务ID}
 */
export function GetCurMaterialSent(data) {
  let params = getRequestParams('live_room-live_room_dispatch-GetCurMaterialSent');

  return request({
    method: 'post',
    url: process.env.VUE_APP_LearnWebSI,
    params,
    data
  });
}

/**
 * 完成推送给我的资料
 * @param { Object } data
 * @returns
 */
export function FinishMyMaterial(data) {
  let params = getRequestParams('live_room-live_room_dispatch-FinishMyMaterial');

  return request({
    method: 'post',
    url: process.env.VUE_APP_LearnWebSI,
    params,
    data
  });
}

/**
 * 得到直播间信息
 * @param {Object} data { task_id 任务ID }
 */
export function GetLiveRoomInfo(data) {
  let params = getRequestParams('live_room-live_room_dispatch-GetLiveRoomInfo');

  return request({
    method: 'post',
    url: process.env.VUE_APP_LearnWebSI,
    params,
    data
  });
}

/**
 * 得到完成了推送课件的学员列表
 * @param {Object} data
 */
export function GetStudentList_FinishMaterial(data) {
  let params = getRequestParams('live_room-live_room_dispatch-GetStudentList_FinishMaterial');

  return request({
    method: 'post',
    url: process.env.VUE_APP_LearnWebSI,
    params,
    data
  });
}
